@@ -19,9 +19,9 @@ import java.net.URL;
 public class GeoGebra extends Object {
 	
 	// GeoGebra version
-	public static final String BUILD_DATE = "July 25, 2010";
+	public static final String BUILD_DATE = "December 17, 2010";
 	
-	public static final String VERSION_STRING = "3.2.44.0";
+	public static final String VERSION_STRING = "3.2.46.0";
 	public static final String SHORT_VERSION_STRING = "3.2"; // used for online archive
 		
 	// File format versions
