@@ -1569,11 +1569,18 @@ public abstract class GeoElement
 				i++;
 				ch = caption.charAt(i);
 				switch (ch) {
-				case 'v': captionSB.append(toValueString());
+				case 'v': 	captionSB.append(toValueString());
 				break;
-				case 'n' : captionSB.append(getLabel());
+				case 'n' : 	captionSB.append(getLabel());
 				break;
-				default : captionSB.append(ch);
+				case 'x' : 	captionSB.append(isGeoPoint() ? kernel.format(((GeoPoint)this).inhomX) : "%x");
+				break;
+				case 'y' : 	captionSB.append(isGeoPoint() ? kernel.format(((GeoPoint)this).inhomY) : "%y");
+				break;
+				case 'z' : 	captionSB.append(isGeoPoint() ? "0" : "%z");
+				break;
+				default : 	captionSB.append('%');
+							captionSB.append(ch);
 				}
 			} else {
 				captionSB.append(ch);
@@ -2576,12 +2583,20 @@ public abstract class GeoElement
 	
 	public String addLabelTextOrHTML(String desc) {
 		String ret; 
-		if (desc.startsWith(label+" ")) {
+		
+		boolean includesEqual = desc.indexOf('=') >= 0;
+		
+		// check for function in desc like "f(x) = x^2" 
+		if (includesEqual && desc.startsWith(label + '(')) {
 			ret = desc;
-		} else {
+		} 
+		else {
 			StringBuffer sb = new StringBuffer();
 			sb.append(label);
-			sb.append(" = ");
+			if (includesEqual)
+				sb.append(": ");
+			else
+				sb.append(" = ");
 			sb.append(desc);
 			ret = sb.toString();
 		}
@@ -2664,7 +2679,7 @@ public abstract class GeoElement
 			if (reverseOrder) {
 				// reverse order: "A point"				
 				sbLongDescHTML.append(' ');
-				sbLongDescHTML.append(typeString);								
+				sbLongDescHTML.append(typeString);
 			}
 
 			// add dependency information
@@ -2923,7 +2938,7 @@ public abstract class GeoElement
 			//	reverse order: "A point"
 			sbNameDescription.append(label);				
 			sbNameDescription.append(' ');			
-			sbNameDescription.append(typeString);			
+			sbNameDescription.append(typeString);
 		}	
 		else {
 			// standard order: "point A"
@@ -2996,7 +3011,7 @@ public abstract class GeoElement
 		if (reverseOrder) {
 			//	reverse order: "A point"
 			sbNameDescriptionHTML.append(' ');
-			sbNameDescriptionHTML.append(typeString);							
+			sbNameDescriptionHTML.append(typeString);
 		}
 		
 		if (addHTMLtag)
@@ -3875,7 +3890,7 @@ public abstract class GeoElement
 					: this.getCommandDescription();
 		}
 		
-		if (ret.equals("") && !this.isGeoText()) {
+		if ("".equals(ret) && !this.isGeoText()) {
 			// eg Text[ (1,2), false]
 			ret = toOutputValueString();
 		}
@@ -3945,6 +3960,8 @@ public abstract class GeoElement
 	}
 	
 	boolean inTree = false;
+
+	private String realLabel;
 	
 	final public boolean isInTree() {
 		return inTree;
@@ -3954,4 +3971,25 @@ public abstract class GeoElement
 		inTree = flag;
 	}
 	
+	/**
+	 * In case this geo is part of macro construction, it
+	 * keeps its own label. To get correct output of Name[geo]
+	 * we need to keep the label of the real-world geo represented by this
+	 * formal geo. 
+	 * 
+	 * @param realLabel Label of the real geo represented by this one
+	 */
+	public void setRealLabel(String realLabel){
+		this.realLabel=realLabel;
+	}
+	
+	/**
+	 * Used for Name command. See {@link #setRealLabel(String)}
+	 * @return label of this geo, or label of a real geo in case this one is formal
+	 */
+	public String getRealLabel(){
+		if(realLabel==null || realLabel.equals(""))return label;
+		return realLabel;
+	}
+	
 }
\ No newline at end of file
