@@ -100,14 +100,14 @@ public abstract class AppletImplementation implements AppletImplementationInterf
 	protected AppletImplementation(JApplet applet) {
 		this.applet = applet;
 
-		// Allow rescaling eg ctrl+ ctrl- in Firefox
-		if (allowRescaling)	applet.addComponentListener(new java.awt.event.ComponentAdapter() {
+		// Allow rescaling/resizing eg ctrl+ ctrl- in Firefox
+		applet.addComponentListener(new java.awt.event.ComponentAdapter() {
 			public void componentResized(ComponentEvent e)
 			{
 				Component c = e.getComponent();
 				Application.debug("Applet resized to: "+c.getWidth()+", "+c.getHeight());
 				
-				if (!app.runningInFrame && app.onlyGraphicsViewShowing())
+				if (allowRescaling && !app.runningInFrame && app.onlyGraphicsViewShowing())
 				{
 					// use just horizontal scale factors
 					// under normal circumstances, these should be the same			
@@ -116,6 +116,7 @@ public abstract class AppletImplementation implements AppletImplementationInterf
 
 				}
 				
+				// these always need updating eg draw reset icon, play/pause icon
 				width = c.getWidth();
 				height = c.getHeight();
 				
@@ -148,6 +149,11 @@ public abstract class AppletImplementation implements AppletImplementationInterf
 	 * in a separate thread.
 	 */
 	public void initInBackground() {	
+		
+		// start animation if wanted by ggb file
+		if (kernel.wantAnimationStarted())
+			kernel.getAnimatonManager().startAnimation();
+		
 		// call JavaScript function ggbOnInit()
 		initJavaScript();
 		Object [] noArgs = { };
@@ -384,12 +390,14 @@ public abstract class AppletImplementation implements AppletImplementationInterf
 		width = cp.getWidth();
 		height = cp.getHeight();	
 		
-		setInitialScaling();
+		if (originalWidth < 0) setInitialScaling();
 		
 		// set move mode
 		app.setMoveMode();			
 	}
 	
+	private int originalWidth = -1, originalHeight = -1;
+
 	/*
 	 * rescales if the width is not what's expected
 	 * eg if browser is zoomed
@@ -398,16 +406,20 @@ public abstract class AppletImplementation implements AppletImplementationInterf
 		if (allowRescaling) {			
 			if (!app.runningInFrame && app.onlyGraphicsViewShowing())
 			{
-				double zoomFactorX = (double)width / (double)app.getEuclidianView().getPreferredSize().getWidth();
-				double zoomFactorY = (double)height / (double)app.getEuclidianView().getPreferredSize().getHeight();
+				originalWidth = (int)ev.getPreferredSize().getWidth();
+				originalHeight = (int)ev.getPreferredSize().getHeight();
+				double zoomFactorX = (double)width / (double)originalWidth;
+				double zoomFactorY = (double)height / (double)originalHeight;
 				double zoomFactor = Math.min(zoomFactorX, zoomFactorY);
-				app.getEuclidianView().zoomAroundCenter(zoomFactor);
+				ev.zoomAroundCenter(zoomFactor);
+			} else {
+				originalWidth = width;
+				originalHeight = height;
 			}
 		}
 
 	}
 
-
 	
 //	/**
 //	 * Initializes the user interface to only show the graphics view.
@@ -767,8 +779,7 @@ public abstract class AppletImplementation implements AppletImplementationInterf
 				return;
 			}
 			app.loadXML(zipFile);
-			return;
-		}
+		} else
 		
 		// avoid security problems calling from JavaScript
 		AccessController.doPrivileged(new PrivilegedAction() {
@@ -789,6 +800,16 @@ public abstract class AppletImplementation implements AppletImplementationInterf
 
 			}
 		});
+		
+		if (allowRescaling) {
+			ev.setTemporarySize(originalHeight, originalWidth);
+			double zoomFactorX = (double)width / (double)originalWidth;
+			double zoomFactorY = (double)height / (double)originalHeight;
+			double zoomFactor = Math.min(zoomFactorX, zoomFactorY);
+			ev.zoomAroundCenter(zoomFactor);
+			ev.setTemporarySize(-1, -1);
+		}
+
 	}
 	
 	/**
